/*
 * Copyright © 2012-2013 Intel Corporation
 *
 * Authors: Rodrigo Moya <rodrigo.moya@collabora.co.uk>
 *          Vivek Dasmohapatra <vivek.dasmohapatra@collabora.co.uk>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef _PACKAGE_MANAGER_H_
#define _PACKAGE_MANAGER_H_

#include <glib-object.h>
#include "utils.h"
#include "diagnostics-view.h"

G_BEGIN_DECLS

#define TYPE_PACKAGE_MANAGER                (package_manager_get_type ())
#define PACKAGE_MANAGER(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PACKAGE_MANAGER, PackageManager))
#define IS_PACKAGE_MANAGER(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PACKAGE_MANAGER))
#define PACKAGE_MANAGER_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PACKAGE_MANAGER, PackageManagerClass))
#define IS_PACKAGE_MANAGER_CLASS(klass)     (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PACKAGE_MANAGER))
#define PACKAGE_MANAGER_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PACKAGE_MANAGER, PackageManagerClass))

typedef struct {
  GObject parent;
} PackageManager;

typedef struct {
  GObjectClass parent_class;

  /* virtual methods */
  gboolean (* is_setup) (PackageManager *manager);
  gboolean (* is_distro_supported) (PackageManager *manager, Configuration *orders);
  gboolean (* setup) (PackageManager *manager);
  gboolean (* run_transaction) (PackageManager *manager);
  gboolean (* clean) (PackageManager *manager);
  gboolean (* is_system_upgraded) (PackageManager *manager, DiagnosticsView *v);

  /* signals */
  void (* error) (PackageManager *manager, const gchar *msg);
  void (* progress) (PackageManager *manager, const gchar *msg);
  void (* detail)  (PackageManager *manager, const gchar *act, const gchar *msg, gint percent);
  void (* setup_finished) (PackageManager *manager);
  void (* transaction_finished) (PackageManager *manager);
  void (* cleanup_finished) (PackageManager *manager);
  
} PackageManagerClass;

GType           package_manager_get_type (void);

PackageManager *package_manager_get (void);
gboolean        package_manager_is_setup (PackageManager *manager);
gboolean        package_manager_is_distro_supported (PackageManager *manager);
gboolean        package_manager_setup (PackageManager *manager);
gboolean        package_manager_run_transaction (PackageManager *manager);
gboolean        package_manager_clean (PackageManager *manager);
gboolean        package_manager_is_system_upgraded (PackageManager *manager, DiagnosticsView *v);

gboolean        package_manager_check_pk_permission (PackageManager *manager, const gchar *action_id);

G_END_DECLS

#endif
